@@ -33,16 +33,19 @@ class TestZohoAuthConfig:
 
 class TestZohoEndpoint:
     @pytest.mark.parametrize(
-        "params,expected",
+        "file_type,params,expected",
         [
-            ({"1": 1}, "patata"),
-            ({"id": 1}, "patata/1"),
-            ({"criteria": "something"}, "patata/search"),
+            (None, {"1": 1}, "patata"),
+            ("photo", {"id": 1}, "patata/1/photo"),
+            ("Attachments", {"id": 1}, "patata/1/Attachments"),
+            (None, {"criteria": "something"}, "patata/search"),
         ],
     )
-    def test_url(self, params: dict, expected: str):
+    def test_url(self, file_type: str, params: dict, expected: str):
         assert (
-            ZohoEndpoint(module_name="patata", method="get", params=params).url
+            ZohoEndpoint(
+                module_name="patata", method="get", params=params, file_type=file_type
+            ).url
             == expected
         )
 
