@@ -1,6 +1,7 @@
 import logging
 import os
 from dataclasses import dataclass, field
+from enum import Enum
 from typing import Dict, List, Tuple
 
 import requests
@@ -47,18 +48,28 @@ class ZohoAuthConfig:
         )
 
 
+class FileTypes(Enum):
+    PHOTO = "photo"
+    ATTACHMENT = "Attachments"
+
+
 @dataclass
 class ZohoEndpoint:
     module_name: str
     method: str
     response_data_key: str = "data"
+    file_type: FileTypes = None
     params: dict = field(default_factory=dict)
     data: dict = field(default_factory=dict)
+    files: dict = field(default_factory=dict)
 
     @property
     def url(self):
         if "id" in self.params:
-            return f"{self.module_name}/{self.params['id']}"
+            record_url = f"{self.module_name}/{self.params['id']}"
+            if self.file_type is not None:
+                record_url = f"{record_url}/{self.file_type}"
+            return record_url
         if "criteria" in self.params:
             return f"{self.module_name}/search"
         return self.module_name
@@ -147,6 +158,7 @@ class ZohoClient:
                 self.zoho_config.api_base_url + zoho_endpoint.url,
                 headers=self.request_headers,
                 json=zoho_endpoint.data,
+                files=zoho_endpoint.files,
             ).json()
         except requests.exceptions.JSONDecodeError:
             return {}
